(***********************************************************************)
(*                                                                     *)
(*                                Sklml                                *)
(*                                                                     *)
(*                 The OCaml parallel skeleton system                  *)
(*                                                                     *)
(*                  projet Estime, INRIA-Rocquencourt                  *)
(*                                                                     *)
(*  Copyright 2007-2011 INRIA.                                         *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  All rights reserved. This file is distributed only by permission.  *)
(*                                                                     *)
(*  Quentin Carbonneaux <Quentin.Carbonneaux@inria.fr>                 *)
(*  Francois Clement <Francois.Clement@inria.fr>                       *)
(*  Pierre Weis <Pierre.Weis@inria.fr>                                 *)
(*                                                                     *)
(***********************************************************************)

(* $Id: make_domain.mli,v 1.6.2.1 2011-09-21 13:08:03 fclement Exp $ *)

type 'a borders = ('a border) list
and 'a border = (int * 'a);;
(** An ['a border] is a couple of an integer which uniquely identify the
    worker who snt it and a data of any type (the border data which is
    application specific). *)

type ('a, 'b) worker_spec = ('a borders, 'a * 'b) Skl.t * int list;;
(** A [('a, 'b) worker_spec] is a description of a subdomain worker, it gives
    its action, a skeleton, and its ``connectivity'', the integer list. This
    list is used to determine which input is needed by the worker currently
    described. *)

val make_domain : (('a, 'b) worker_spec) array -> ('b array, bool) Skl.t ->
  ('a array, ('a * 'b) array) Skl.t
;;
(** Effectively builds the domain skeleton from a given spec and one
    convergence predicate. *)

val make_f_domain : (('a, 'b) worker_spec) array -> ('b array -> bool) ->
  ('a array, ('a * 'b) array) Skl.t
;;
(** In case your predicate is a simple function, this version should be
    used instead of [make_domain], it will be a tad more efficient.
    Warning: you must use this function at toplevel in your program,
    before calling [pardo] because it will register skeletons depending
    on its arguments. *)

(** Optimal versions, currently unsafe *)

val make_domain_opt : (('a, 'b) worker_spec) array -> ('b array, bool) Skl.t ->
  ('a array, ('a * 'b) array ) Skl.t
;;

val make_f_domain_opt : (('a, 'b) worker_spec) array -> ('b array -> bool) ->
  ('a array, ('a * 'b) array) Skl.t
;;

